/*
 * CS356 Project 01 -- Elevator Simulator
 *
 * Elevator Class Specification
 */

#ifndef ELEVATOR_HPP
#define ELEVATOR_HPP

#include <iostream>
#include <list>
#include "direction.hpp"
#include "position.hpp"
#include "stop.hpp"

typedef enum { CLOSED, OPEN } DoorStatus;
typedef std::list<Stop> StopList;

class Elevator
{
	public:
		Elevator ();

		void stop_at (Stop &stop);
		float distance_from (Position& pos) const;
		void move ();
		bool is_idle () const;

	private:
		/* Callbacks into the GUI */
		void open_door () const;
		void close_door () const;
		void update_position () const;

		/* Analyze the list of stops */
		bool currently_at_stop () const;

		/* Elevator Status Variables */
		DoorStatus	door_;
		Direction	direction_;
		Position	current_position_;
		StopList	stops_;

		const float	ELEVATOR_STEP;
};


#endif /* ELEVATOR_HPP */

/* vim: set ts=4 sts=4 sw=4 noexpandtab textwidth=112: */
