#include "stop.hpp"

Stop::Stop (const Position& position, const Direction& direction)
	: position_(position)
	, direction_(direction)
{
	// Intentionally Left Empty
}

bool Stop::operator== (const Stop& rhs) const
{
	if (rhs.position_ != position_)
		return false;

	if (direction_ == ALL || rhs.direction_ == ALL)
		return true;

	return (rhs.direction_ == direction_);
}

bool Stop::operator< (const Stop& rhs) const
{
	/* If we do not use the direction to help differentiate, then it is
	 * possible that an object can be neither less, greater, or equal */
	return ((position_ < rhs.position_) || (direction_ < rhs.direction_));
}

bool Stop::operator> (const Stop& rhs) const
{
	return (position_ > rhs.position_);
}

const Direction Stop::getDirection () const
{
	return direction_;
}

std::ostream& operator<< (std::ostream& os, const Stop& rhs)
{
	os << "Stop(" << rhs.position_ << ", " << rhs.direction_ << ")";
	return os;
}


/* vim: set ts=4 sts=4 sw=4 noexpandtab textwidth=112: */
